boofun.analysis.communication\_complexity
=========================================

.. automodule:: boofun.analysis.communication_complexity


   .. rubric:: Functions

   .. autosummary::

      cc_disjointness
      cc_equality
      cc_inner_product
      deterministic_cc
      discrepancy
      fooling_set_bound
      get_communication_matrix
      log_rank_bound
      rectangle_partition_bound

   .. rubric:: Classes

   .. autosummary::

      CommunicationComplexityProfile
      CommunicationMatrix
